#' Fresh 'Shiny' Themes
#'
#' Customize 'Bootstrap' and 'Bootswatch' themes, like colors, fonts, grid layout, to use in 'Shiny' applications.
#'
#' @name fresh
#' @author Victor Perrier & Fanny Meyer (\href{https://twitter.com/dreamRs_fr}{@@dreamRs_fr})
"_PACKAGE"
